@@ -20,7 +20,7 @@ class XRayConfigurator:
                 plugins=eval(xray.get("PLUGINS", "'ECSPlugin', 'EC2Plugin'")),
                 sampling=xray.getboolean("SAMPLING", False),
                 stream_sql=xray.getboolean("STREAM_SQL", True),
-                daemon=xray.get("DAEMON", "xray-daemon:2000"))
+                daemon_address=xray.get("DAEMON", "xray-daemon:2000"))
             patch_all()
 
             if xray.getboolean("SQLALCHEMY", True):
